@@ -23,6 +23,29 @@ sub _parse_scalar {
     if (not defined $value) {
         $ret = $ddp->maybe_colorize('undef', 'undef');
     }
+    elsif ( $ddp->show_dualvar ) {
+        my $numified;
+        $numified = do { no warnings 'numeric'; 0+ $value } if defined $value;
+        if ( $numified ) {
+            if ( $value eq "$numified" ) {
+                $ret = $ddp->maybe_colorize($value, 'number');
+            }
+            else {
+                $ret = Data::Printer::Common::_process_string( $ddp, "$value", 'string' );
+                my $quote = $ddp->maybe_colorize( $ddp->scalar_quotes, 'quotes' );
+                $ret = $quote . $ret . $quote;
+                $ret .= ' (dualvar: ' . $ddp->maybe_colorize( $numified, 'number' ) . ')';
+            }
+        }
+        elsif ( !$numified && _is_number($value) ) {
+            $ret = $ddp->maybe_colorize($value, 'number');
+        }
+        else {
+            $ret = Data::Printer::Common::_process_string($ddp, $value, 'string');
+            my $quote = $ddp->maybe_colorize($ddp->scalar_quotes, 'quotes');
+            $ret = $quote . $ret . $quote;
+        }
+    }
     elsif (_is_number($value)) {
         $ret = $ddp->maybe_colorize($value, 'number');
     }
